# Anilistpy ![anilistpy](https://avatars3.githubusercontent.com/u/75199724?s=30&v=4)
An easy to use python3 wrapper for anilist.co APIv2

```
pip install anilistpy
```
 
Documenation and Examples on the the [gh-page](https://anilistpy.github.io)

![agpl3](https://upload.wikimedia.org/wikipedia/commons/thumb/0/06/AGPLv3_Logo.svg/200px-AGPLv3_Logo.svg.png)